<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.Devices.HumanInterfaceDevice

Windows Runtime (WinRT) APIs for for the `Windows.Devices.HumanInterfaceDevice` namespace.

This package provides the `winrt.windows.devices.humaninterfacedevice` module.
